Addon class abstract Writing Your Own Addons Custom Addons

Implementers
Annotations

Constructors

Addon({required String id})
const

Properties

controllerMapFactory ControllerMapFactory
Experimental: This is not tested and might change in the future or even be removed.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
A string that uniquely identifies this addon.
final
layers AddonLayerEntries
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildConfigureTabControlSections(BuildContext context) List<ConfigureControlSection>
Builds the control sections to be added into the "CONFIGURE" tab.
buildDescription(BuildContext context) AddonDescription?
Add a description to the addon. This may be used in multiple ways and places in the future. For instance, the InfoAddon displays these descriptions on the homepage, if it is configured to do so.
buildHomePageComponents(BuildContext context) List<HomePageComponent>
Builds a list of HomePageComponent for the homepage. This method can be overridden to provide custom components for the homepage.
buildInspectTabControlSections(BuildContext context) List<InspectControlSection>
Builds the control sections to be added into the "INSPECT" tab.
buildLocalizationsDelegates(BuildContext context) List<LocalizationsDelegate<Object?>>
Builds the LocalizationsDelegates that are use for UI introduced by this addon. These localizations are not meant to be used inside the use case itself, but only for the UI that conceptually belongs to the interface of the addon.
buildSettingsTabControlSections(BuildContext context) List<SettingsControlSection>
Builds the control sections to be added into the "ADDON" tab.
createRetainedUseCaseStateEntries() List<AnyRetainedUseCaseStateEntry>
Creates RetainedUseCaseStateEntrys which can keep state for the whole lifetime of the use case. The created retained state entries can be retrieved via the UseCaseComposition returned by UseCaseAccessor.compositionOf. See UseCaseAccessor on how to obtain an instance.
createTransientUseCaseStateEntries() List<AnyTransientUseCaseStateEntry>
Creates TransientUseCaseStateEntrys which are attached to the UseCaseComposer at the beginning of the use case setup. The created transient state entries can be retrieved via the UseCaseComposition returned by UseCaseAccessor.compositionOf. See UseCaseAccessor on how to obtain an instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited