AddonConfig class Getting Started File Structure Configuring Addons

A class that defines which addons are used. This needs to be passed to a WerkbankApp or DisplayApp. If you are using both, make sure to pass the same AddonConfig in order to ensure consistent behavior.

Constructors

AddonConfig({required List<Addon> addons, bool includeDefaultAddons = true})
Constructs an AddonConfig using the provided addons and unless includeDefaultAddons is set to false, the default addons.
factory

Properties

addons List<Addon>
The list of addons that are used.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited