appOnly property

bool appOnly
final

Whether this entry should only be inserted only when in the context of a WerkbankApp. So if the use case is displayed for example by a UseCaseDisplay, this layer will not be inserted.

For more fine grained control of how widgets are built depending on whether they are in a WerkbankApp or not, use AddonLayerAccessor.environmentOf to get the current environment.

Implementation

final bool appOnly;