AppConfig class abstract interface Getting Started File Structure Customizing the AppConfig

A class that defines how to build the app widget, which is typically one of MaterialApp, CupertinoApp, or WidgetsApp.

This needs to be passed to a WerkbankApp or DisplayApp. If you are using both, make sure to pass the same AppConfig in order to ensure consistent behavior.

Constructors

AppConfig({required AppBuilder buildApp, TransitionBuilder? additionalBuilder, required WrapperBuilder defaultTextStyleBuilder, required ThemeBrightnessBuilder themeBrightnessBuilder})
A constructor which defines an AppConfig using callbacks.
factory
AppConfig.cupertino({TransitionBuilder? additionalBuilder})
A constructor which defines an AppConfig for a cupertino app.
factory
AppConfig.material({TransitionBuilder? additionalBuilder})
A constructor which defines an AppConfig for a material app.
factory
AppConfig.widgets({TransitionBuilder? additionalBuilder, required WrapperBuilder defaultTextStyleBuilder, required ThemeBrightnessBuilder themeBrightnessBuilder})
A constructor which defines an AppConfig for a widgets app.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildApp(BuildContext context, TransitionBuilder builder, Widget home) Widget
Builds the app widget. This is typically one of MaterialApp, CupertinoApp, or WidgetsApp.
buildDefaultTextStyle(BuildContext context, Widget child) Widget
Wraps the child with a default text style widget, which defines the default text style for the use cases.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
themeBrightness(BuildContext context) Brightness
Returns the current Brightness for the app theme, given a context where the theme can be accessed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited