ControlSection class

Constructors

ControlSection({required ControlSectionId id, required Widget title, required bool visible, required List<Widget> children})
const

Properties

children List<Widget>
final
hashCode int
The hash code for this object.
no setterinherited
id ControlSectionId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title Widget
final
visible bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() ControlSectionId
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited