DisplayApp class Display Testing with Use Cases

A widget that sets up the app for displaying use cases without the UI of a WerkbankApp. Usually one or more UseCaseDisplay widgets as descendants to display the use cases. Alternatively, the convenience constructor DisplayApp.singleUseCase can be used to display a single use case.

Inheritance

Constructors

DisplayApp({Key? key, required AppConfig appConfig, required AddonConfig addonConfig, required Widget child})
const
DisplayApp.singleUseCase({required AppConfig appConfig, required AddonConfig addonConfig, required UseCaseDescriptor useCase, UseCaseStateMutation? initialMutation, WrapperBuilder? useCaseWrapper})
A convenience constructor to create a DisplayApp with a UseCaseDisplay as child.
factory

Properties

addonConfig AddonConfig
final
appConfig AppConfig
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited