UseCaseAccessor mixin

A mixin that provides access to data in the BuildContext that is available from every place where there is a specific use case in the BuildContext.

This includes widgets built inside

To obtain an instance of this mixin call the static access field on the class listed above from which the widgets you want to access the data in are built.

Superclass constraints
Mixin applications

Properties

containerName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addonByIdOf(BuildContext context, String addonId) Addon?
Returns the Addon by the given addonId if it is active, or null if not.
inherited
addonsOf(BuildContext context) List<Addon>
Returns a list of all active Addons.
inherited
compositionOf(BuildContext context) UseCaseComposition
Gets the UseCaseComposition of the current use case.
ensureNotNull<T extends Object>(T? value) → T
inherited
ensureReturns<T>(T function()) → T
inherited
isAddonActiveOf(BuildContext context, String addonId) bool
Returns whether the Addon with the given addonId is active.
inherited
maybeUseCaseEnvironmentOf(BuildContext context) UseCaseEnvironment?
Gets the UseCaseEnvironment of the current use case.
metadataOf(BuildContext context) UseCaseMetadata
Gets the UseCaseMetadata of the current use case.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
useCaseOf(BuildContext context) UseCaseDescriptor
Gets the UseCaseDescriptor of the current use case.

Operators

operator ==(Object other) bool
The equality operator.
inherited