UseCaseOverlayLayerEntry class
- Inheritance
-
- Object
- AddonLayerEntry
- UseCaseOverlayLayerEntry
Constructors
-
UseCaseOverlayLayerEntry({required String id, bool includeInOverlay = true, List<
FullLayerEntryId> before = const [], List<FullLayerEntryId> after = const [], SortHint sortHint = SortHint.central, required AddonLayerWidgetBuilder builder}) -
const
Properties
-
after
→ List<
FullLayerEntryId> -
Ensures that this AddonLayerEntry is inserted after
the AddonLayerEntrys identified by the given FullLayerEntryIds.
finalinherited
- appOnly → bool
-
Whether this entry should only be inserted only when in the context of a
WerkbankApp.
So if the use case is displayed for example by a
UseCaseDisplay, this layer will not be inserted.
finalinherited
-
before
→ List<
FullLayerEntryId> -
Ensures that this AddonLayerEntry is inserted before the
AddonLayerEntrys identified by the given FullLayerEntryIds.
finalinherited
- builder → AddonLayerWidgetBuilder
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
A string that uniquely identifies this layer within the addon it is used
in.
finalinherited
- includeInOverlay → bool
-
Whether this entry should be inserted when the use case is displayed
as the thumbnail in the overview.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortHint → SortHint
-
Gives a hint approximately where within the layer this AddonLayerEntry
should be inserted.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited