WTreeNode class

Constructors

WTreeNode({required LocalKey key, required Widget title, Widget? leading, Widget? trailing, Widget? body, bool isInitiallyExpanded = false, List<WTreeNode>? children, VoidCallback? onTap, bool isSelected = false, bool isVisible = true})

Properties

body Widget?
final
children List<WTreeNode>?
final
hashCode int
The hash code for this object.
no setterinherited
isInitiallyExpanded bool
final
isSelected bool
final
isVisible bool
final
key LocalKey
final
leading Widget?
final
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title Widget
final
trailing Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited