WerkbankApp class Welcome Getting Started

The main entry point for a Werkbank.

Minimal example:

WerkbankApp(
  name: 'Projekt Name',
  logo: const YourLogo(),
  appConfig: AppConfig.material(),
  addonConfig: AddonConfig(addons: []),
  // The root of your use case tree.
  root: root,
);
Inheritance

Constructors

WerkbankApp({required String name, DateTime? lastUpdated, required AppConfig appConfig, required AddonConfig addonConfig, required WerkbankRoot root, Key? key})
const

Properties

addonConfig AddonConfig
The AddonConfig to be used by the WerkbankApp.
final
appConfig AppConfig
The AppConfig used for the use cases.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lastUpdated DateTime? Getting Started
The date when the data was last updated.
final
The logo of your project that this WerkbankApp is for.
final
name String
The name of your project that this WerkbankApp is for.
final
root WerkbankRoot
The root of the use case tree.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited