appConfig property
The AppConfig used for the use cases.
This defines how the app widget is built, which is typically one of MaterialApp, CupertinoApp, or WidgetsApp. The AppConfigs for these can be created using AppConfig.material, AppConfig.cupertino and AppConfig.widgets respectively. For custom app widgets, use the default AppConfig constructor or create a custom implementation of AppConfig.
Implementation
final AppConfig appConfig;