lastUpdated property

DateTime? lastUpdated
final

The date when the data was last updated.

If you are deploying the werkbank with a CI, you can set this using an environment variable with an ISO 8601 date of the build time. For example like this:

const lastUpdatedDate = String.fromEnvironment('last_updated_date');
return WerkbankApp(
  // ...
  lastUpdated: lastUpdatedDate.isEmpty
    ? DateTime.now()
    : DateTime.parse(lastUpdatedDate),
  // ...
);

Implementation

final DateTime? lastUpdated;