WerkbankChildNode class sealed

A WerkbankNode which is a child of a WerkbankParentNode.

The subclasses are WerkbankComponent, WerkbankFolder, and WerkbankUseCase.

Inheritance
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the node.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited