name property
The name of the node.
This will be displayed in the UI and used in the path when accessing use cases via a URL.
Implementation
final String name;
The name of the node.
This will be displayed in the UI and used in the path when accessing use cases via a URL.
final String name;