WerkbankFolder class Getting Started Structure

A WerkbankNode that defines a collection of WerkbankNodes.

This can be used to group multiple WerkbankUseCases, WerkbankComponents, and other WerkbankFolders together.

Inheritance
Implemented types

Constructors

WerkbankFolder({required String name, bool isInitiallyCollapsed = false, UseCaseParentBuilder? builder, required List<WerkbankChildNode> children})

Properties

builder UseCaseParentBuilder?
The UseCaseParentBuilder for this node.
finalinherited
children List<WerkbankChildNode>
The children of this node.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isInitiallyCollapsed bool
final
name String
The name of the node.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited