AddonConfig class Getting Started File Structure Configuring Addons
A class that defines which addons are used. This needs to be passed to a WerkbankApp or DisplayApp. If you are using both, make sure to pass the same AddonConfig in order to ensure consistent behavior.
Constructors
-
AddonConfig({required List<
Addon> addons, bool includeDefaultAddons = true}) -
Constructs an AddonConfig using the provided
addonsand unlessincludeDefaultAddonsis set tofalse, the default addons.factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited