AddonLayerEntry class
Constructors
-
AddonLayerEntry({required String id, required bool appOnly, required bool includeInOverlay, required List<
FullLayerEntryId> before, required List<FullLayerEntryId> after, required SortHint sortHint, required AddonLayerWidgetBuilder builder}) -
const
Properties
-
after
→ List<
FullLayerEntryId> -
Ensures that this AddonLayerEntry is inserted after
the AddonLayerEntrys identified by the given FullLayerEntryIds.
final
- appOnly → bool
-
Whether this entry should only be inserted only when in the context of a
WerkbankApp.
So if the use case is displayed for example by a
UseCaseDisplay, this layer will not be inserted.
final
-
before
→ List<
FullLayerEntryId> -
Ensures that this AddonLayerEntry is inserted before the
AddonLayerEntrys identified by the given FullLayerEntryIds.
final
- builder → AddonLayerWidgetBuilder
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
A string that uniquely identifies this layer within the addon it is used
in.
final
- includeInOverlay → bool
-
Whether this entry should be inserted when the use case is displayed
as the thumbnail in the overview.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortHint → SortHint
-
Gives a hint approximately where within the layer this AddonLayerEntry
should be inserted.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited