includeInOverlay property
Whether this entry should be inserted when the use case is displayed as the thumbnail in the overview.
This is not applicable in every AddonLayer, since not every layer
is displayed within the main view where the overview is shown.
If this is not applicable, this is set to true.
For more fine grained control of how widgets are built depending on whether they are in the overview or not, use UseCaseAccessor.maybeUseCaseEnvironmentOf to get the current UseCaseEnvironment.
Implementation
final bool includeInOverlay;