ControlSection class
Constructors
-
ControlSection({required ControlSectionId id, required Widget title, required bool visible, required List<
Widget> children}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → ControlSectionId -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited