FullAccessNotificationsController class
- Inheritance
-
- Object
- ChangeNotifier
- FullAccessNotificationsController
- Implemented types
Constructors
- FullAccessNotificationsController({required TickerProvider vsync})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
notificationSubscriptionMap
→ IMap<
LocalKey, NotificationSubscription> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vsync → TickerProvider
-
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispatch(
WerkbankNotification notification, {bool count = true}) → NotificationSubscription -
override
-
dispose(
) → void -
Discards any resources used by the object.
override
-
disposeNotification(
LocalKey notificationKey) → void -
getNotificationSubscriptionByKey(
{required LocalKey key}) → NotificationSubscription? -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited