UseCaseDescriptor class
- Inheritance
-
- Object
- Descriptor
- UseCaseDescriptor
- Implemented types
Properties
-
childNodePath
→ Iterable<
WerkbankChildNode> -
Gets the node path from root to this node, excluding the root node.
no setterinherited
- depth → int
-
Gets the depth of the node within the tree.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInRoot → bool
-
no setterinherited
-
nameSegments
→ List<
String> -
no setterinherited
- node → WerkbankUseCase
-
no setteroverride
-
nodePath
→ List<
WerkbankNode> -
Gets the node path from root to this node, including the root node.
finalinherited
- path → String
-
no setterinherited
-
pathSegments
→ List<
String> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
computeMetadata(
AddonConfig addonConfig) → UseCaseMetadata -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited