UseCaseLayoutLayerEntryAccessor class
- Inheritance
-
- Object
- AddonAccessor
- AddonLayerAccessor
- UseCaseLayoutLayerEntryAccessor
- Mixed-in types
Constructors
- UseCaseLayoutLayerEntryAccessor()
-
const
Properties
- containerName → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addonByIdOf(
BuildContext context, String addonId) → Addon? -
Returns the Addon by the given
addonIdif it is active, ornullif not.inherited -
addonsOf(
BuildContext context) → List< Addon> -
Returns a list of all active Addons.
inherited
-
compositionOf(
BuildContext context) → UseCaseComposition -
Gets the UseCaseComposition of the current use case.
inherited
-
ensureNotNull<
T extends Object> (T? value) → T -
inherited
-
ensureReturns<
T> (T function()) → T -
inherited
-
environmentOf(
BuildContext context) → WerkbankEnvironment -
Gets the WerkbankEnvironment of the current addon.
This is one of WerkbankEnvironment.app or
WerkbankEnvironment.display.
This can be used by addons for example to omit certain visual overlays
or similar with a DisplayApp widget, since they only make
sense in an environment where the user interacts with
the WerkbankApp application.
inherited
-
isAddonActiveOf(
BuildContext context, String addonId) → bool -
Returns whether the Addon with the given
addonIdis active.inherited -
maybeAcknowledgedController(
BuildContext context) → AcknowledgedController? -
Gets the AcknowledgedController of the current WerkbankApp if
we are currently in the context of a WerkbankApp.
inherited
-
maybeAddonSpecificationsOf(
BuildContext context) → Map< String, AddonSpecification> ? -
Get a map from Addon.ids to AddonSpecifications for all all addons
that are currently used.
inherited
-
maybeHistoryOf(
BuildContext context) → HistoryController? -
Gets the HistoryController of the current WerkbankApp if
we are currently in the context of a WerkbankApp.
inherited
-
maybeLastUpdatedOf(
BuildContext context) → DateTime? -
Gets the last updated date of the current WerkbankApp if
we are currently in the context of a WerkbankApp.
inherited
-
maybeLogoOf(
BuildContext context) → Widget? -
Gets the logo of the current WerkbankApp if
we are currently in the context of a WerkbankApp.
inherited
-
maybeMetadataForUseCaseOf(
BuildContext context, UseCaseDescriptor useCase) → UseCaseMetadata? -
Gets the UseCaseMetadata of the given UseCaseDescriptor if
we are currently in the context of a WerkbankApp.
inherited
-
maybeMetadataMapOf(
BuildContext context) → Map< UseCaseDescriptor, UseCaseMetadata> ? -
Returns a map of all UseCaseDescriptors to their UseCaseMetadatas
if we are currently in the context of a WerkbankApp.
inherited
-
Gets the current NavState if we are currently in the context of a
WerkbankApp.
inherited
-
maybePersistentControllerOf<
T extends PersistentController> (BuildContext context) → T? -
Gets the PersistentController of the given type
if we are currently in the
context of a WerkbankApp.
inherited
-
Reads the current NavState without creating a dependency
if we are currently in the context of a
WerkbankApp.
inherited
-
maybeRootDescriptorOf(
BuildContext context) → RootDescriptor? -
Gets the RootDescriptor of the current WerkbankApp if
we are currently in the context of a WerkbankApp.
inherited
-
maybeRouterOf(
BuildContext context) → WerkbankRouter? -
Gets the WerkbankRouter for the current WerkbankApp if
we are currently in the context of a WerkbankApp.
inherited
-
maybeUseCaseEnvironmentOf(
BuildContext context) → UseCaseEnvironment? -
Gets the UseCaseEnvironment of the current use case.
inherited
-
maybeUseCaseViewportSizeOf(
BuildContext context) → Size? - Gets the Size of the current viewport of the use case if we are currently in the context of a WerkbankApp.
-
maybeWerkbankNameOf(
BuildContext context) → String? -
Gets the name of the current WerkbankApp if
we are currently in the context of a WerkbankApp.
inherited
-
metadataOf(
BuildContext context) → UseCaseMetadata -
Gets the UseCaseMetadata of the current use case.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
useCaseOf(
BuildContext context) → UseCaseDescriptor -
Gets the UseCaseDescriptor of the current use case.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited