WerkbankComponent class Getting Started File Structure Structure
A WerkbankNode that defines a collection of WerkbankUseCases. This is typically used when there are multiple use cases for a single component, such as a button or a switch.
To group multiple use cases together which do not show off the same component, consider using a WerkbankFolder instead.
- Inheritance
-
- Object
- WerkbankNode
- WerkbankParentNode<
WerkbankUseCase> - WerkbankComponent
- Implemented types
Constructors
-
WerkbankComponent({required String name, bool isInitiallyCollapsed = false, UseCaseParentBuilder? builder, required List<
WerkbankUseCase> useCases})
Properties
- builder → UseCaseParentBuilder?
-
The UseCaseParentBuilder for this node.
finalinherited
-
children
→ List<
WerkbankUseCase> -
The children of this node.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitiallyCollapsed → bool
-
final
- name → String
-
The name of the node.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited