WerkbankParentNode<T extends WerkbankChildNode> class
sealed
A superclass for WerkbankNodes which can have children.
Specifically the subclasses are WerkbankRoot, WerkbankComponent and WerkbankFolder.
- Inheritance
-
- Object
- WerkbankNode
- WerkbankParentNode
- Implementers
Properties
- builder → UseCaseParentBuilder?
-
The UseCaseParentBuilder for this node.
final
-
children
→ List<
T> -
The children of this node.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited