WerkbankRoot class Getting Started Structure
A WerkbankNode that defines a collection of WerkbankChildNodes.
An instance of this is passed to the WerkbankApp to define the structure of the app.
The children define your tree structure of WerkbankFolders, WerkbankComponents, and WerkbankUseCases.
- Inheritance
-
- Object
- WerkbankNode
- WerkbankParentNode<
WerkbankChildNode> - WerkbankRoot
Constructors
-
WerkbankRoot({UseCaseParentBuilder? builder, required List<
WerkbankChildNode> children})
Properties
- builder → UseCaseParentBuilder?
-
The UseCaseParentBuilder for this node.
finalinherited
-
children
→ List<
WerkbankChildNode> -
The children of this node.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited